==> webpdf-wsclient-2.0.0-sources.jar: net/webpdf/wsclient/schema/extraction/info/TransitionType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TransitionType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TransitionType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="objectKey" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="page" default="0"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="autoScroll" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="flyScale" type="{http://www.w3.org/2001/XMLSchema}float" default="1" /&gt;
 *       &lt;attribute name="flyAreaOpaque" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="duration" default="1"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}float"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="style" type="{http://schema.webpdf.de/1.0/extraction/info}TransitionStyleType" /&gt;
 *       &lt;attribute name="direction" type="{http://schema.webpdf.de/1.0/extraction/info}TransitionDirection" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TransitionType")
public class TransitionType {

    @XmlAttribute(name = "objectKey")
    protected String objectKey;
    @XmlAttribute(name = "page")
    protected Integer page;
    @XmlAttribute(name = "autoScroll")
    protected Boolean autoScroll;
    @XmlAttribute(name = "flyScale")
    protected Float flyScale;
    @XmlAttribute(name = "flyAreaOpaque")
    protected Boolean flyAreaOpaque;
    @XmlAttribute(name = "duration")
    protected Float duration;
    @XmlAttribute(name = "style")
    protected TransitionStyleType style;
    @XmlAttribute(name = "direction")
    protected TransitionDirection direction;

    /**
     * Gets the value of the objectKey property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getObjectKey() {
        if (objectKey == null) {
            return "";
        } else {
            return objectKey;
        }
    }

    /**
     * Sets the value of the objectKey property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setObjectKey(String value) {
        this.objectKey = value;
    }

    public boolean isSetObjectKey() {
        return (this.objectKey!= null);
    }

    /**
     * Gets the value of the page property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getPage() {
        if (page == null) {
            return  0;
        } else {
            return page;
        }
    }

    /**
     * Sets the value of the page property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setPage(int value) {
        this.page = value;
    }

    public boolean isSetPage() {
        return (this.page!= null);
    }

    public void unsetPage() {
        this.page = null;
    }

    /**
     * Gets the value of the autoScroll property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isAutoScroll() {
        if (autoScroll == null) {
            return false;
        } else {
            return autoScroll;
        }
    }

    /**
     * Sets the value of the autoScroll property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAutoScroll(boolean value) {
        this.autoScroll = value;
    }

    public boolean isSetAutoScroll() {
        return (this.autoScroll!= null);
    }

    public void unsetAutoScroll() {
        this.autoScroll = null;
    }

    /**
     * Gets the value of the flyScale property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getFlyScale() {
        if (flyScale == null) {
            return  1.0F;
        } else {
            return flyScale;
        }
    }

    /**
     * Sets the value of the flyScale property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setFlyScale(float value) {
        this.flyScale = value;
    }

    public boolean isSetFlyScale() {
        return (this.flyScale!= null);
    }

    public void unsetFlyScale() {
        this.flyScale = null;
    }

    /**
     * Gets the value of the flyAreaOpaque property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isFlyAreaOpaque() {
        if (flyAreaOpaque == null) {
            return false;
        } else {
            return flyAreaOpaque;
        }
    }

    /**
     * Sets the value of the flyAreaOpaque property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setFlyAreaOpaque(boolean value) {
        this.flyAreaOpaque = value;
    }

    public boolean isSetFlyAreaOpaque() {
        return (this.flyAreaOpaque!= null);
    }

    public void unsetFlyAreaOpaque() {
        this.flyAreaOpaque = null;
    }

    /**
     * Gets the value of the duration property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getDuration() {
        if (duration == null) {
            return  1.0F;
        } else {
            return duration;
        }
    }

    /**
     * Sets the value of the duration property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setDuration(float value) {
        this.duration = value;
    }

    public boolean isSetDuration() {
        return (this.duration!= null);
    }

    public void unsetDuration() {
        this.duration = null;
    }

    /**
     * Gets the value of the style property.
     * 
     * @return
     *     possible object is
     *     {@link TransitionStyleType }
     *     
     */
    public TransitionStyleType getStyle() {
        return style;
    }

    /**
     * Sets the value of the style property.
     * 
     * @param value
     *     allowed object is
     *     {@link TransitionStyleType }
     *     
     */
    public void setStyle(TransitionStyleType value) {
        this.style = value;
    }

    public boolean isSetStyle() {
        return (this.style!= null);
    }

    /**
     * Gets the value of the direction property.
     * 
     * @return
     *     possible object is
     *     {@link TransitionDirection }
     *     
     */
    public TransitionDirection getDirection() {
        return direction;
    }

    /**
     * Sets the value of the direction property.
     * 
     * @param value
     *     allowed object is
     *     {@link TransitionDirection }
     *     
     */
    public void setDirection(TransitionDirection value) {
        this.direction = value;
    }

    public boolean isSetDirection() {
        return (this.direction!= null);
    }

}

==> webpdf-wsclient-2.0.3-sources.jar: net/webpdf/wsclient/schema/extraction/info/TransitionType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TransitionType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TransitionType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="objectKey" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="page" default="0"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="autoScroll" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="flyScale" type="{http://www.w3.org/2001/XMLSchema}float" default="1" /&gt;
 *       &lt;attribute name="flyAreaOpaque" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="duration" default="1"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}float"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="style" type="{http://schema.webpdf.de/1.0/extraction/info}TransitionStyleType" default="none" /&gt;
 *       &lt;attribute name="direction" type="{http://schema.webpdf.de/1.0/extraction/info}TransitionDirection" default="none" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TransitionType")
public class TransitionType {

    @XmlAttribute(name = "objectKey")
    protected String objectKey;
    @XmlAttribute(name = "page")
    protected Integer page;
    @XmlAttribute(name = "autoScroll")
    protected Boolean autoScroll;
    @XmlAttribute(name = "flyScale")
    protected Float flyScale;
    @XmlAttribute(name = "flyAreaOpaque")
    protected Boolean flyAreaOpaque;
    @XmlAttribute(name = "duration")
    protected Float duration;
    @XmlAttribute(name = "style")
    protected TransitionStyleType style;
    @XmlAttribute(name = "direction")
    protected TransitionDirection direction;

    /**
     * Gets the value of the objectKey property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getObjectKey() {
        if (objectKey == null) {
            return "";
        } else {
            return objectKey;
        }
    }

    /**
     * Sets the value of the objectKey property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setObjectKey(String value) {
        this.objectKey = value;
    }

    public boolean isSetObjectKey() {
        return (this.objectKey!= null);
    }

    /**
     * Gets the value of the page property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getPage() {
        if (page == null) {
            return  0;
        } else {
            return page;
        }
    }

    /**
     * Sets the value of the page property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setPage(int value) {
        this.page = value;
    }

    public boolean isSetPage() {
        return (this.page!= null);
    }

    public void unsetPage() {
        this.page = null;
    }

    /**
     * Gets the value of the autoScroll property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isAutoScroll() {
        if (autoScroll == null) {
            return false;
        } else {
            return autoScroll;
        }
    }

    /**
     * Sets the value of the autoScroll property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAutoScroll(boolean value) {
        this.autoScroll = value;
    }

    public boolean isSetAutoScroll() {
        return (this.autoScroll!= null);
    }

    public void unsetAutoScroll() {
        this.autoScroll = null;
    }

    /**
     * Gets the value of the flyScale property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getFlyScale() {
        if (flyScale == null) {
            return  1.0F;
        } else {
            return flyScale;
        }
    }

    /**
     * Sets the value of the flyScale property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setFlyScale(float value) {
        this.flyScale = value;
    }

    public boolean isSetFlyScale() {
        return (this.flyScale!= null);
    }

    public void unsetFlyScale() {
        this.flyScale = null;
    }

    /**
     * Gets the value of the flyAreaOpaque property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isFlyAreaOpaque() {
        if (flyAreaOpaque == null) {
            return false;
        } else {
            return flyAreaOpaque;
        }
    }

    /**
     * Sets the value of the flyAreaOpaque property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setFlyAreaOpaque(boolean value) {
        this.flyAreaOpaque = value;
    }

    public boolean isSetFlyAreaOpaque() {
        return (this.flyAreaOpaque!= null);
    }

    public void unsetFlyAreaOpaque() {
        this.flyAreaOpaque = null;
    }

    /**
     * Gets the value of the duration property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getDuration() {
        if (duration == null) {
            return  1.0F;
        } else {
            return duration;
        }
    }

    /**
     * Sets the value of the duration property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setDuration(float value) {
        this.duration = value;
    }

    public boolean isSetDuration() {
        return (this.duration!= null);
    }

    public void unsetDuration() {
        this.duration = null;
    }

    /**
     * Gets the value of the style property.
     * 
     * @return
     *     possible object is
     *     {@link TransitionStyleType }
     *     
     */
    public TransitionStyleType getStyle() {
        if (style == null) {
            return TransitionStyleType.NONE;
        } else {
            return style;
        }
    }

    /**
     * Sets the value of the style property.
     * 
     * @param value
     *     allowed object is
     *     {@link TransitionStyleType }
     *     
     */
    public void setStyle(TransitionStyleType value) {
        this.style = value;
    }

    public boolean isSetStyle() {
        return (this.style!= null);
    }

    /**
     * Gets the value of the direction property.
     * 
     * @return
     *     possible object is
     *     {@link TransitionDirection }
     *     
     */
    public TransitionDirection getDirection() {
        if (direction == null) {
            return TransitionDirection.NONE;
        } else {
            return direction;
        }
    }

    /**
     * Sets the value of the direction property.
     * 
     * @param value
     *     allowed object is
     *     {@link TransitionDirection }
     *     
     */
    public void setDirection(TransitionDirection value) {
        this.direction = value;
    }

    public boolean isSetDirection() {
        return (this.direction!= null);
    }

}
